#Bubot Core
IoT python framework based on OCF specification.

Package contains basic primitives.


##Licensing

This published under the MIT License, see [LICENSE](LICENSE) for details.


Copyright (c) 2019 Mikhail Razgovorov 

